pug_server library
Server-side Dart wrapper for Pug.js using a persistent Node.js server.
This library provides a way to use Pug templates in server-side Dart applications by communicating with a long-running Node.js server via Unix domain sockets.
Classes
- PugServer
- Server-side Pug wrapper that communicates with a persistent Node.js server.
Exceptions / Errors
- PugServerException
- Exception thrown when Pug server operations fail.